clear
set more off
set mem 500m


********************************************************************************************************************************************
*Purpose: 
*This do file analyses information disclosed to identify the relationship between different measures of scale and network and non-network opex	
*for EDBs using econometric analysis
*The result of this analysis will be used to project changes in opex resulting from changes in scale for the EDB starting price adjustment																				
********************************************************************************************************************************************

*this file  uses eststo, which needs to be installed before this file runs

***************************
*Prepare data for analysis*
***************************

*IMPORT DATA:
insheet using "Opex data.csv", double clear
*Note: Data in real terms (2011 prices)

*RENAME VARIABLES
rename  	edbid 					id
rename 	yearending 					year
rename 	totalcontrollableopex 			opex
rename 	directopex 					direct
rename	indirectopex				indirect
rename 	generalmanagementadministrationa	general_admin_ovhead
rename	passthroughcosts				passthrough
rename	refurbishmentandrenewalmaintenan	refurb_renewal	
rename	routineandpreventativemaintenanc	routine_prevent 
rename 	systemmanagementandoperations000	management_operations
rename 	faultandemergencymaintenance000	fault_ems
rename 	aclossrentalrebatespassedon000	ac_loss_rebates
rename 	other000					other
rename 	totalopex000				total_opex	
rename	totalcircuitlengthforsupply		circuit_length_total
rename 	numberofconnectionpointsatyearen 	icp_total
rename	electricityenteringsystemforsupp	electricity_entering
rename	electricitysuppliedtocustomersco	electricity_supplied
rename  	capitalexpenditureonnonsystemfix	nsfa_capex
rename	totalcapitalexpenditureonsystemf	sfa_capex

*FIX TYPO:
replace edb = "Marlborough" if edb == "Marlerough"

*GENERATE NEW VARIBALES:
gen icp_km = icp_total/circuit_length_total
label var icp_km "ICPs per km of circuit"

gen energy_density =  electricity_supplied/icp_total
label var energy_density "Electricity supplied per ICP"

gen exempt = 0
label var exempt "indicates exempt EDB"
replace exempt = 1 if edb == "Buller" | edb == "Counties" | edb == "Electra" | edb == "Mainpower" | edb == "Marlborough" ///
| edb == "Waitaki" | edb == "Northpower" | edb == "Scanpower" | edb == "TPCL" | edb == "Waipa" | edb == "WEL" | edb == "Westpower"


*DROP NEGATIVE VALUES (IF ANY)
foreach var in opex direct indirect {
	replace `var' = 0 if `var' < 0
}


*GENERATE LOGS:
foreach var in opex direct indirect circuit_length_total  electricity_entering electricity_supplied icp_total {
	gen l`var' = ln(`var')
}


*EXCLUDE VARIABLES NOT NEEDED
drop  general_admin_ovhead management_operations routine_prevent refurb_renewal fault_ems passthrough ac_loss_rebates other  nsfa_capex sfa_capex

*EXCLUDE VECTOR AND WELLINGTON DATA FROM 2009 AS DE-MERGER OCCURED MID YEAR. THEREFORE THE RELATIONSHIP BETWEEN EXPENDITURE AND SCALE
*IS LIKELY YO BE DISTORTED
drop if edb == "Vector" & year == 2009 | edb == "Wellington" & year == 2009

*EXCLUDE ORION DATA FROM 2011 (2010 DATA ADJUSTED BY CPI)
drop if edb == "Orion" & year == 2011

*GENERATE VARIABLES TO TEST WHETHER COEFFICIENT DIFFER FOR EXEMPT EDBS
gen lcircuit_exempt 	= lcircuit_length_total*exempt
gen licp_exempt 		= licp_total*exempt
gen lelectricity_exempt = lelectricity_supplied*exempt
gen icp_km_exempt		= icp_km*exempt

*GENERATE VARIABLES TO TEST WHETHER COEFFICIENT DIFFERS BY YEAR
foreach year in 2008 2009 2010 2011 {
	gen y`year' = 0
	replace y`year' = 1 if year == `year'
*include interaction terms
	gen lcircuit_`year' 	= lcircuit_length_total*y`year'
	gen licp_`year' 		= licp_total*y`year'
	gen lelectricity_`year' = lelectricity_supplied*y`year'
	gen icp_km_`year' 	= icp_km*y`year'
	gen lcircuit_exempt_`year' = lcircuit_exempt*y`year'
}

*EXCLUDE NETWORK AND NON-NETWORK OPEX PRIOR TO 2010 AS NOT ALL EDBS REPORT AND DATA APPEARS INCONSISTENT
replace direct 	= . if year < 2010
replace indirect 	= . if year < 2010
replace direct 	= . if direct == 0
replace indirect 	= . if indirect == 0

replace ldirect 		= . if year < 2010
replace lindirect 	= . if year < 2010

save opex1, replace	/*To be used later for Roy-Zellner test of time pooled effects - see end of .do file*/

*DECLARE AS PANEL DATA
tsset id  year, yearly


*********************
*REGRESSION ANALYSIS*
*********************



****************************
*Regression of network opex*
****************************

*RUN POTENTIAL MODELS TO START IDENTIFYING PREFERRED MODELS
eststo clear 
foreach scale in lcircuit_length_total lelectricity_supplied licp_total "lcircuit_length_total lelectricity_supplied" "lcircuit_length_total licp_total" ///
"lcircuit_length_total lelectricity_supplied icp_km" "lcircuit_length_total licp_total icp_km"	{
	eststo: reg ldirect `scale' 
}
estout using "network opex.xls", cells(b(star fmt(%9.3f))) stats(r2_a)  replace

*PERFORM STATISTICAL TESTS ON SELECTED MODELS (selected based on intuition, adjusted R2 and statistical significance):
foreach scale in lcircuit_length_total lelectricity_supplied licp_total "lcircuit_length_total lelectricity_supplied" "lcircuit_length_total licp_total" {
	reg ldirect  `scale' 
	ovtest
	hettest
	imtest
}
*->Most models fails heteroscedasticity tests -> use robust standard errors
foreach scale in lcircuit_length_total lelectricity_supplied licp_total "lcircuit_length_total lelectricity_supplied" "lcircuit_length_total licp_total" {
	reg ldirect  `scale', robust 
	ovtest
}
*-> results indicate no omitted variables

*Test impact of excluding exempt EDBs:	
foreach scale in lcircuit_length_total lelectricity_supplied licp_total "lcircuit_length_total lelectricity_supplied" "lcircuit_length_total licp_total"  {
	reg ldirect  `scale' if exempt == 0, robust
	ovtest
}
*-> results indicate no omitted variables


*TEST WHETHER COEFFICIENTS DIFFER FOR EXEMPT EDBS (SIMILAR TO CHOW TEST)
reg ldirect lcircuit_length_total lcircuit_exempt exempt, robust
test lcircuit_exempt exempt
reg ldirect lelectricity_supplied  lelectricity_exempt exempt, robust
test lelectricity_exempt exempt
reg ldirect licp_total licp_exempt exempt, robust
test licp_exempt exempt
reg ldirect lcircuit_length_total lcircuit_exempt lelectricity_supplied  lelectricity_exempt exempt, robust
test lcircuit_exempt lelectricity_exempt exempt
reg ldirect lcircuit_length_total licp_total lcircuit_exempt  licp_exempt exempt, robust
test lcircuit_exempt  licp_exempt exempt
*The exempt EDB effects are jointly significant, except when circuit length is used as the sole driver

*PREFERRED MODELS
reg ldirect lcircuit_length_total, robust
reg ldirect lelectricity_supplied, robust		
reg ldirect lelectricity_supplied if exempt == 0, robust


*TEST WHETHER POOLED PANEL MODEL IS APPROPRIATE:
*Initial test
reg ldirect lcircuit_length_total y2010  lcircuit_2010 , robust
test  lcircuit_2010 
*->pooled panel model is appropriate as we cannot reject the null hypothesis that the coefficients each year differ from zero 
reg ldirect lelectricity_supplied  lelectricity_2010 , robust
test lelectricity_2010 
*->pooled panel model is appropriate as we cannot reject the null hypothesis that the coefficients each year differ from zero 
reg ldirect lelectricity_supplied lelectricity_2010 if exempt == 0, robust
test lelectricity_2010 
*->pooled panel model is appropriate as we cannot reject the null hypothesis that the coefficients each year differ from zero 

*ROY-ZELLNER TEST ACROSS CROSS SECTIONS
xi,prefix(I) i.id
gen Iid_1=1 if id==1
replace Iid_1=0 if id!=1
foreach var of varlist  lcircuit_length_total lelectricity_supplied {
	foreach num of numlist 1(1)29 {
	gen `var'_`num'=`var'*Iid_`num'
}
}
*Note: Roy-Zellner test for time fixed effects provided at the end of this do. file

*CHOW TEST (as an alternative test for poolability)
reg ldirect lcircuit_length_total, robust
scalar R2OLS=_result(7)
scalar RRSSOLS=_result(4)
*Test formula: scalar F_pool= ((RRSOLS-SUMURSS)/((n-1)*kprime))/((SUMURSS)/(n*(t-kprime)))
quietly regress ldirect lcircuit_length_total if id==1
scalar RRS_1=_result(4)
quietly regress ldirect lcircuit_length_total if id==2
scalar RRS_2=_result(4)
quietly regress ldirect lcircuit_length_total if id==3
scalar RRS_3=_result(4)
quietly regress ldirect lcircuit_length_total if id==4
scalar RRS_4=_result(4)
quietly regress ldirect lcircuit_length_total if id==5
scalar RRS_5=_result(4)
quietly regress ldirect lcircuit_length_total if id==6
scalar RRS_6=_result(4)
quietly regress ldirect lcircuit_length_total if id==7
scalar RRS_7=_result(4)
quietly regress ldirect lcircuit_length_total if id==8
scalar RRS_8=_result(4)
quietly regress ldirect lcircuit_length_total if id==9
scalar RRS_9=_result(4)
quietly regress ldirect lcircuit_length_total if id==10
scalar RRS_10=_result(4)
quietly regress ldirect lcircuit_length_total if id==11
scalar RRS_11=_result(4)
quietly regress ldirect lcircuit_length_total if id==12
scalar RRS_12=_result(4)
quietly regress ldirect lcircuit_length_total if id==13
scalar RRS_13=_result(4)
quietly regress ldirect lcircuit_length_total if id==14
scalar RRS_14=_result(4)
quietly regress ldirect lcircuit_length_total if id==15
scalar RRS_15=_result(4)
quietly regress ldirect lcircuit_length_total if id==16
scalar RRS_16=_result(4)
*regress ldirect lcircuit_length_total if id==17
scalar RRS_17=_result(4)
quietly regress ldirect lcircuit_length_total if id==18
scalar RRS_18=_result(4)
quietly regress ldirect lcircuit_length_total if id==19
scalar RRS_19=_result(4)
quietly regress ldirect lcircuit_length_total if id==20
scalar RRS_20=_result(4)
quietly regress ldirect lcircuit_length_total if id==21
scalar RRS_21=_result(4)
quietly regress ldirect lcircuit_length_total if id==22
scalar RRS_22=_result(4)
quietly regress ldirect lcircuit_length_total if id==23
scalar RRS_23=_result(4)
quietly regress ldirect lcircuit_length_total if id==24
scalar RRS_24=_result(4)
quietly regress ldirect lcircuit_length_total if id==25
scalar RRS_25=_result(4)
quietly regress ldirect lcircuit_length_total if id==26
scalar RRS_26=_result(4)
quietly regress ldirect lcircuit_length_total if id==27
scalar RRS_27=_result(4)
quietly regress ldirect lcircuit_length_total if id==28
scalar RRS_28=_result(4)
quietly regress ldirect lcircuit_length_total if id==29
scalar RRS_29=_result(4)

scalar SUMURSS= RRS_1+RRS_2+ RRS_3+RRS_4+RRS_5+RRS_6+RRS_7+RRS_8+RRS_9+RRS_11+RRS_12+RRS_13+RRS_14+RRS_15+RRS_16+RRS_18+RRS_19+RRS_20+RRS_21+RRS_22+RRS_23+RRS_24+RRS_25+RRS_26+RRS_27+RRS_28

scalar df_apool=(28-1)*1
scalar df_npool= 28*(2-1)
scalar F_pool= ((RRSSOLS-SUMURSS)/df_apool)/(SUMURSS/df_npool)
scalar list F_pool
*->conclude: poolability is inconclusive due to insufficient observations


*TEST FOR CONSTANT RETURNS TO SCALE
reg ldirect lcircuit_length_total, robust
test lcircuit_length_total = 1
reg ldirect lelectricity_supplied
test lelectricity_supplied = 1
xtreg ldirect lelectricity_supplied if exempt == 0
test lelectricity_supplied = 1
*-> indicates CRS for circuit length and electricity supplier for non-exempt EDBs, but not for electricity supplied on the full sample 


*TEST BETWEEN LOGS AND LEVELS (DAVIDSON-MCKINNON TEST)
foreach scale in circuit_length_total electricity_supplied {
	reg ldirect  l`scale', robust
	predict res, res
	reg direct `scale' res, robust
	test res
	drop res
}
*->coefficient on residual is staistically significant, indicating log model is appropriate

*QUANTILE REGRESSION
foreach scale in circuit_length_total electricity_supplied {
	sqreg ldirect l`scale', quantile(0.25 0.5 0.75) 
	test [q25]l`scale' = [q50]l`scale'
	test [q25]l`scale' = [q75]l`scale'
	test [q50]l`scale' = [q75]l`scale'
*-> cannot reject null hypothesis that coefficients are equal across quantiles
}
sqreg ldirect lelectricity_supplied if exempt == 0, quantile(0.25 0.5 0.75)
test [q25]lelectricity_supplied = [q50]lelectricity_supplied
test [q25]lelectricity_supplied = [q75]lelectricity_supplied
test [q50]lelectricity_supplied = [q75]lelectricity_supplied
*-> can  reject null hypothesis that coefficients are equal across quantiles



*TEST PREDICTIVE POWER OF MODEL
*generate line to indicate over or under-prediction of opex
gen line = 6 if year == 2008
replace line = 8 if year == 2009
replace line = 10 if year == 2010
replace line = 11 if year == 2011
gen line2 = 6 if year == 2008
replace line2 = 8 if year == 2009
replace line2 = 10 if year == 2010
replace line2 = 11 if year == 2011

reg ldirect lcircuit_length_total, robust
predict yhat, xb
scatter ldirect yhat if exempt == 0, mlabel(edb) xscale(r(6(1)11))  xlabel(#6) xtitle("ln(network opex)") ytitle("Predicted ln(network opex)") ///
|| line line line2, legend(off)
*Note: Below line indicates model under-predicts opex. Above line indicates model over-predicts opex
drop yhat

reg ldirect lelectricity_supplied, robust
predict yhat, xb
scatter ldirect yhat if exempt == 0, mlabel(edb) xscale(r(6(1)11))  xlabel(#6) xtitle("ln(network opex)") ytitle("Predicted ln(network opex)") ///
|| line line line2, legend(off)
drop yhat

reg ldirect lelectricity_supplied if exempt == 0, robust
predict yhat, xb
scatter ldirect yhat if exempt == 0, mlabel(edb) xscale(r(6(1)11))  xlabel(#6) xtitle("ln(network opex)") ytitle("Predicted ln(network opex)") ///
|| line line line2, legend(off)
drop yhat

drop line line2


*PREFERRED MODELS 
eststo clear
eststo: reg ldirect lcircuit_length_total, robust 	/*MOST PREFERRED MODEL*/
eststo: reg ldirect lcircuit_length_total if exempt == 0, robust 	
eststo: reg ldirect lelectricity_supplied, robust
eststo: reg ldirect lelectricity_supplied if exempt == 0, robust

gen outlier = 1 if edb == "Nelson" & year == 2010
replace outlier = 1 if edb == "Vector"
eststo: reg ldirect lcircuit_length_total if outlier != 1, robust 	/*outlier sensitivity - see below*/

estout using "network opex.xls", cells(b(star fmt(%9.3f))) stats(r2_a N F) starlevels(* 0.10 ** 0.05 *** 0.01) replace
eststo clear



**********************
*Sensitivity analysis* 
**********************

*WEIGHTED REGRESSION
*Generate weight
by year, sort: egen sum_circuit_length = sum(circuit_length_total)
label var sum_circuit_length "Industry total circuit length"
*Note: decrease in cicuit length in 2011 due to no data for Orion. 
gen weight_circuit = circuit_length_total/sum_circuit_length
label var weight_circuit "Weight based on circuit length"

*Test effect of a weighted regression relative to preferred model
reg ldirect lcircuit_length_total [aw=weight_circuit], robust
*-> has little impact on the coefficients. Prefer to give all EDBs equal weight.

drop  sum_circuit_length weight_circuit

*IMPACT OF OUTLIERS
*outlier code:
capture program drop test_outlier
program define test_outlier

predict yhattt, xb
predict e, residuals
predict lev, leverage
predict dfits, dfits
predict wd, welsch
predict cooksd, cooksd

gen k = e(df_m) + 1 

list edb dfits if abs(dfits)>2*sqrt(k/e(N))
list edb cooksd if abs(cooksd)>4/e(N)
list edb wd if abs(wd)>3*sqrt(k)
list edb lev if lev>((2*k)/e(N))

gen g1=1 if abs(dfits)>2*sqrt(k/e(N)) 
gen dfits_outlier_stat=abs(dfits)
scatter e yhattt , msize(small) scale(0) || scatter e yhattt if g1==1, mcolor(red) ///
msymbol() msize(small) yline(0) || scatter e yhattt if g1==1, mcolor(red) msymbol() ///
msize(small) yline(0) mlabel(edb) mlabcolor(blue) ///
saving(DFITS, replace)

gen g2=1 if abs(cooksd)>4/e(N)
gen cooksd_outlier_stat=abs(cooksd)
scatter e yhattt, msize(small) scale(0) || scatter e yhattt if g2==1, ///
mcolor(red) msymbol() msize(small) yline(0) || scatter e yhattt if g2==1, mcolor(red) ///
msymbol() msize(small) yline(0) mlabel(edb) mlabcolor(blue) ///
saving(Cooks_distance, replace)

gen g3=1 if abs(wd)>3*sqrt(k)
gen wd_outlier_stat=abs(wd)
scatter e yhattt, msize(small) scale(0) || scatter e yhattt if g3==1, mcolor(red) ///
msymbol() msize(small) yline(0) || scatter e yhattt if g3==1, mcolor(red) ///
msymbol() msize(small) yline(0) mlabel(edb) mlabcolor(blue) ///
saving(Welsch_distance, replace)

gen g4=1 if lev>((2*k)/e(N))
gen lev_outlier_stat=abs(lev)
scatter e yhattt, msize(small) scale(0) || scatter e yhattt if g4==1, mcolor(red) ///
msymbol() msize(small) yline(0) || scatter e yhattt if g4==1, mcolor(red) ///
msymbol() msize(small) yline(0) mlabel(edb) mlabcolor(blue) ///
saving(leverage, replace)

drop yhattt e lev dfits wd cooksd k 
end

reg ldirect lcircuit_length_total
test_outlier

foreach var in g1 g2 g3 g4 {
	replace `var' = 0 if `var' == .
	replace `var' = 0 if year < 2010	/*data prior to 2010 not included in model*/
}
gen sum_outlier = g1 + g2 + g3 + g4
label var sum_outlier "Indicates if observation a potential outlier"
list edb year sum_outlier if sum_outlier > 1
*-> suggest Vector might be an outlier. Run model excluding Vector.

reg ldirect lcircuit_length_total, robust
reg ldirect lcircuit_length_total if edb != "Vector", robust
*-> coefficient is not statistically different. However, include as a sensitivity

drop g1 g2 g3 g4  dfits_outlier_stat cooksd_outlier_stat wd_outlier_stat lev_outlier_stat sum_outlier outlier




*****************************
*Non-network opex regression*
*****************************

*RUN POTENTIAL MODELS TO START IDENTIFYING PREFERRED MODELS
eststo clear 
foreach scale in lcircuit_length_total lelectricity_supplied licp_total "lcircuit_length_total lelectricity_supplied" "lcircuit_length_total licp_total" ///
"lcircuit_length_total lelectricity_supplied icp_km" "lcircuit_length_total licp_total icp_km"	"lcircuit_length_total energy_density" "lelectricity_supplied energy_density" ///
"lcircuit_length_total icp_km" {
	eststo: reg lindirect `scale' 
}
estout using "non network opex.xls", cells(b(star fmt(%9.3f))) stats(r2_a N)  replace
eststo clear 


*PERFORM STATISTICAL TESTS ON SELECTED MODELS (selected based on intuition, adjusted R2 and statistical significance):
foreach scale in lcircuit_length_total lelectricity_supplied licp_total "lcircuit_length_total lelectricity_supplied icp_km" {
	reg lindirect  `scale' 
	ovtest
	hettest
	imtest
}
*->Most models fails one or more heteroscedasticity tests -> use robust standard errors
foreach scale in lcircuit_length_total lelectricity_supplied licp_total "lcircuit_length_total lelectricity_supplied icp_km" {
	reg lindirect  `scale', robust 
	ovtest
}
*-> Model using circuit length only fails RESET test. All other models pass, but not at 10%

*Test impact of excluding exempt EDBs:	
foreach scale in lcircuit_length_total lelectricity_supplied licp_total "lcircuit_length_total lelectricity_supplied icp_km" {
	reg lindirect  `scale' if exempt == 0, robust
	ovtest
}
*-> Model using circuit length only fails RESET test. All other models pass.


*TEST WHETHER COEFFICIENTS DIFFER FOR EXEMPT EDBS (SIMILAR TO CHOW TEST)
reg lindirect lcircuit_length_total lcircuit_exempt exempt, robust
test lcircuit_exempt exempt
reg lindirect lelectricity_supplied  lelectricity_exempt exempt, robust
test lelectricity_exempt exempt
reg lindirect licp_total licp_exempt exempt, robust
test licp_exempt exempt
reg lindirect lcircuit_length_total lcircuit_exempt lelectricity_supplied  lelectricity_exempt icp_km icp_km_exempt exempt, robust
test lcircuit_exempt lelectricity_exempt icp_km_exempt exempt
*The exempt EDB effects are jointly insignificant 

*PREFERRED MODELS
reg lindirect lcircuit_length_total, robust
reg lindirect lcircuit_length_total lelectricity_supplied icp_km, robust	
reg lindirect lelectricity_supplied, robust	


*TEST WHETHER POOLED PANEL MODEL IS APPROPRIATE:
reg lindirect lcircuit_length_total y2010 lcircuit_2010, robust
test lcircuit_2010 
*->pooled panel model is appropriate as we cannot reject the null hypothesis that the coefficients each year differ from zero 
reg lindirect lcircuit_length_total lelectricity_supplied icp_km y2010 lcircuit_2010 lelectricity_2010  icp_km_2010, robust	
test lcircuit_2010   lelectricity_2010   icp_km_2010
*->pooled panel model is appropriate as we cannot reject the null hypothesis that the coefficients each year differ from zero 
reg lindirect lelectricity_supplied y2010  lelectricity_2010, robust	
test lelectricity_2010
*->pooled panel model is appropriate as we cannot reject the null hypothesis that the coefficients each year differ from zero 

*ROY-ZELLNER TEST ACROSS CROSS SECTIONS
foreach var of varlist lelectricity_supplied icp_km {
foreach num of numlist 1(1)29 {
	capture gen `var'_`num'=`var'*Iid_`num'
}
}

*quietly xtreg lindirect lcircuit_length_total_*, re
*->insufficient observations
*test (lcircuit_length_total_1= lcircuit_length_total_2= lcircuit_length_total_3= lcircuit_length_total_4= lcircuit_length_total_5= lcircuit_length_total_6= lcircuit_length_total_7= lcircuit_length_total_8= lcircuit_length_total_9= lcircuit_length_total_10= lcircuit_length_total_11= lcircuit_length_total_12= lcircuit_length_total_13= lcircuit_length_total_14= lcircuit_length_total_15= lcircuit_length_total_16= lcircuit_length_total_17= lcircuit_length_total_18= lcircuit_length_total_19= lcircuit_length_total_20= lcircuit_length_total_21= lcircuit_length_total_22= lcircuit_length_total_23= lcircuit_length_total_24= lcircuit_length_total_25= lcircuit_length_total_26= lcircuit_length_total_27= lcircuit_length_total_28= lcircuit_length_total_29)

*quietly xtreg lindirect lcircuit_length_total_* lelectricity_supplied icp_km_*, re
*->insufficient observations
*test (lelectricity_supplied_1=lelectricity_supplied_2=lelectricity_supplied_3=lelectricity_supplied_4=lelectricity_supplied_5=lelectricity_supplied_6=lelectricity_supplied_7=lelectricity_supplied_8=lelectricity_supplied_9=lelectricity_supplied_10=lelectricity_supplied_11=lelectricity_supplied_12=lelectricity_supplied_13=lelectricity_supplied_14=lelectricity_supplied_15=lelectricity_supplied_16=lelectricity_supplied_17=lelectricity_supplied_18=lelectricity_supplied_19=lelectricity_supplied_20=lelectricity_supplied_21=lelectricity_supplied_22=lelectricity_supplied_23=lelectricity_supplied_24=lelectricity_supplied_25=lelectricity_supplied_26=lelectricity_supplied_27=lelectricity_supplied_28=lelectricity_supplied_29)(lelectricity_supplied icp_km_1=lelectricity_supplied icp_km_2=lelectricity_supplied icp_km_3=lelectricity_supplied icp_km_4=lelectricity_supplied icp_km_5=lelectricity_supplied icp_km_6=lelectricity_supplied icp_km_7=lelectricity_supplied icp_km_8=lelectricity_supplied icp_km_9=lelectricity_supplied icp_km_10=lelectricity_supplied icp_km_11=lelectricity_supplied icp_km_12=lelectricity_supplied icp_km_13=lelectricity_supplied icp_km_14=lelectricity_supplied icp_km_15=lelectricity_supplied icp_km_16=lelectricity_supplied icp_km_17=lelectricity_supplied icp_km_18=lelectricity_supplied icp_km_19=lelectricity_supplied icp_km_20=lelectricity_supplied icp_km_21=lelectricity_supplied icp_km_22=lelectricity_supplied icp_km_23=lelectricity_supplied icp_km_24=lelectricity_supplied icp_km_25=lelectricity_supplied icp_km_26=lelectricity_supplied icp_km_27=lelectricity_supplied icp_km_28=lelectricity_supplied icp_km_29)

*quietly xtreg lindirect lelectricity_supplied_*, re
*->insufficient observations
*test (lelectricity_supplied_1=lelectricity_supplied_2=lelectricity_supplied_3=lelectricity_supplied_4=lelectricity_supplied_5=lelectricity_supplied_6=lelectricity_supplied_7=lelectricity_supplied_8=lelectricity_supplied_9=lelectricity_supplied_10=lelectricity_supplied_11=lelectricity_supplied_12=lelectricity_supplied_13=lelectricity_supplied_14=lelectricity_supplied_15=lelectricity_supplied_16=lelectricity_supplied_17=lelectricity_supplied_18=lelectricity_supplied_19=lelectricity_supplied_20=lelectricity_supplied_21=lelectricity_supplied_22=lelectricity_supplied_23=lelectricity_supplied_24=lelectricity_supplied_25=lelectricity_supplied_26=lelectricity_supplied_27=lelectricity_supplied_28=lelectricity_supplied_29)

*TEST FOR CONSTANT RETURNS TO SCALE
reg lindirect lcircuit_length_total lelectricity_supplied icp_km, robust	
test _b[lcircuit_length_total] + _b[lelectricity_supplied] = 1
reg lindirect lcircuit_length_total, robust
test lcircuit_length_total = 1
reg lindirect lelectricity_supplied, robust	
test lelectricity_supplied = 1
reg lindirect lcircuit_length_total lelectricity_supplied icp_km if exempt == 0, robust	
test (lcircuit_length_total + lelectricity_supplied) = 1
*-> indicates economies of scale


*TEST BETWEEN LOGS AND LEVELS (DAVIDSON-MCKINNON TEST)
foreach scale in lcircuit_length_total lelectricity_supplied "lcircuit_length_total lelectricity_supplied" "lcircuit_length_total lelectricity_supplied icp_km" {
foreach level in circuit_length_total electricity_supplied "circuit_length_total electricity_supplied" "circuit_length_total electricity_supplied icp_km" {
	reg lindirect  `scale', robust
	predict res, res
	reg indirect `level' res, robust
	test res
	drop res
}
}
*->coefficient on the residual is positive and significant, indicating log model is appropriate

*QUANTILE REGRESSION
sqreg lindirect lcircuit_length_total , quantile(0.25 0.5 0.75)
test [q25]lcircuit_length_total = [q50]lcircuit_length_total
test [q25]lcircuit_length_total = [q75]lcircuit_length_total
test [q50]lcircuit_length_total = [q75]lcircuit_length_total
*-> cannot reject null hypothesis that coefficients are equal across quantiles

sqreg lindirect lelectricity_supplied, quantile(0.25 0.5 0.75)
test [q25]lelectricity_supplied = [q50]lelectricity_supplied
test [q25]lelectricity_supplied = [q75]lelectricity_supplied
test [q50]lelectricity_supplied = [q75]lelectricity_supplied
*-> reject null hypothesis that coefficients are equal across quantiles. However cannot reject when exclude exempt EDBs

sqreg lindirect lcircuit_length_total lelectricity_supplied icp_km, quantile(0.25 0.5 0.75)
test [q25]lcircuit_length_total = [q50]lcircuit_length_total
test [q25]lcircuit_length_total = [q75]lcircuit_length_total
test [q50]lcircuit_length_total = [q75]lcircuit_length_total
test [q25]lelectricity_supplied = [q50]lelectricity_supplied
test [q25]lelectricity_supplied = [q75]lelectricity_supplied
test [q50]lelectricity_supplied = [q75]lelectricity_supplied
test [q25]icp_km = [q50]icp_km
test [q25]icp_km = [q75]icp_km
test [q50]icp_km = [q75]icp_km
*-> cannot reject null hypothesis that coefficients are equal across quantiles 

*TEST PREDICTIVE POWER OF MODEL
*generate line to indicate over or under-prediction of opex
gen line = 6 if year == 2008
replace line = 8 if year == 2009
replace line = 10 if year == 2010
replace line = 11 if year == 2011
gen line2 = 6 if year == 2008
replace line2 = 8 if year == 2009
replace line2 = 10 if year == 2010
replace line2 = 11 if year == 2011

reg lindirect lcircuit_length_total, robust
predict yhat, xb
scatter lindirect yhat if exempt == 0, mlabel(edb) xscale(r(6(1)11))  xlabel(#6) xtitle("ln(non-network opex)") ytitle("Predicted ln(non-network opex)") ///
|| line line line2, legend(off)
*Note: Below line indicates model under-predicts opex. Above line indicates model over-predicts opex
drop yhat

reg lindirect lcircuit_length_total lelectricity_supplied icp_km, robust
predict yhat, xb
scatter lindirect yhat if exempt == 0, mlabel(edb) xscale(r(6(1)11))  xlabel(#6) xtitle("ln(non-network opex)") ytitle("Predicted ln(non-network opex)") ///
|| line line line2, legend(off)
drop yhat

reg lindirect lelectricity_supplied, robust	
predict yhat, xb
scatter lindirect yhat if exempt == 0, mlabel(edb) xscale(r(6(1)11))  xlabel(#6) xtitle("ln(non-network opex)") ytitle("Predicted ln(non-network opex)") ///
|| line line line2, legend(off)
drop yhat

reg lindirect lcircuit_length_total lelectricity_supplied icp_km if exempt == 0, robust	
predict yhat, xb
scatter lindirect yhat if exempt == 0, mlabel(edb) xscale(r(6(1)11))  xlabel(#6) xtitle("ln(non-network opex)") ytitle("Predicted ln(non-network opex)") ///
|| line line line2, legend(off)
drop yhat

drop line line2


*PREFERRED MODELS
eststo clear
eststo: reg lindirect lcircuit_length_total lelectricity_supplied icp_km, robust	/*MOST PREFERRED MODEL*/
*NOTE: Model preferred to one excluding exempt EDBs as observations consistent with network model
eststo: reg lindirect lcircuit_length_total lelectricity_supplied icp_km if exempt == 0, robust	
eststo: reg lindirect lcircuit_length_total, robust
eststo: reg lindirect lelectricity_supplied, robust
gen outlier = 1 if edb == "Buller" & year == 2011
eststo: reg lindirect lcircuit_length_total lelectricity_supplied icp_km if outlier != 1, robust	/*See outlier sensitivity analysis below*/
estout using "non network opex.xls", cells(b(star fmt(%9.3f))) stats(r2_a N F)  starlevels(* 0.10 ** 0.05 *** 0.01) replace

drop outlier

**********************
*Sensitivity analysis* 
**********************

*WEIGHTED REGRESSION
*Generate weight
by year, sort: egen sum_circuit_length = sum(circuit_length_total)
label var sum_circuit_length "Industry total circuit length"
*Note: decrease in cicuit length in 2011 due to no data for Orion. 
gen weight_circuit = circuit_length_total/sum_circuit_length
label var weight_circuit "Weight based on circuit length"

by year, sort: egen sum_electricity = sum(electricity_supplied)
label var sum_electricity "Industry total electricity supplied"
*Note: decrease in 2011 due to no data for Orion. 
gen weight_electricity = electricity_supplied/sum_electricity
label var weight_electricity "Weight based on electricity supplied"

*Test effect of a weighted regression relative to preferred model
reg lindirect lcircuit_length_total lelectricity_supplied icp_km, robust
reg lindirect lcircuit_length_total lelectricity_supplied icp_km [aw=weight_circuit], robust
reg lindirect lcircuit_length_total lelectricity_supplied icp_km [aw=weight_electricity], robust
*-> has relatively little impact on the coefficients. Prefer to give all EDBs equal weight.
drop  sum_circuit_length weight_circuit  sum_electricity weight_electricity


*IMPACT OF OUTLIERS
reg lindirect lcircuit_length_total lelectricity_supplied icp_km
test_outlier

foreach var in g1 g2 g3 g4 {
	replace `var' = 0 if `var' == .
	replace `var' = 0 if year < 2010	/*data prior to 2010 not included in model*/
}
gen sum_outlier = g1 + g2 + g3 + g4
label var sum_outlier "Indicates if observation a potential outlier"
list edb year sum_outlier if sum_outlier > 1
*-> suggest Buller might be an outlier in 2011. Run model excluding Buller.

reg lindirect lcircuit_length_total lelectricity_supplied icp_km, robust
gen outlier = 1 if edb == "Buller" & year == 2011
reg lindirect lcircuit_length_total lelectricity_supplied icp_km if outlier != 1 , robust
*-> coefficient is not statistically different. However, include as a sensitivity

drop g1 g2 g3 g4  dfits_outlier_stat cooksd_outlier_stat wd_outlier_stat lev_outlier_stat sum_outlier outlier


/*
*******************************************************************************
*TEST POOLABILITY FOR TIME EFFECTS ON NETWORK AND NON-NETWORK PREFERRED MODELS*
*******************************************************************************

*Roy-Zellner approach

use opex1.dta, clear
keep if year>2007

xi,prefix(Y) i.year
gen Yyear_2008=1 if year==2008
replace Yyear_2008=0 if year!=2008
rename  Yyear_2008 Yyear_1 
rename  Yyear_2009 Yyear_2
rename  Yyear_2010 Yyear_3
rename  Yyear_2011 Yyear_4

foreach var of varlist lcircuit_length_total lelectricity_supplied icp_km {
	foreach num of numlist 1(1)4{
		gen `var'_`num'=`var'*Yyear_`num'
}
}

*Network models
quietly xtreg ldirect lcircuit_length_total_*, re i(year)
*lcircuit_length_total_1 and lcircuit_length_total_2 dropped due to collinearity, so we only tested regressors 3 and 4)
test (lcircuit_length_total_3= lcircuit_length_total_4)
*->conclude: we can pool the data across time

quietly xtreg ldirect  lelectricity_supplied_*, re i(year)
*lelectricity_supplied_1 and lelectricity_supplied_2 dropped due to collinearity  so we only tested regressors 3 and 4)
test(lelectricity_supplied_3=lelectricity_supplied_4)
*->conclude: we can pool the data across time
 
quietly xtreg ldirect  lelectricity_supplied_* if exempt==0, re i(year)
*lelectricity_supplied_1 and lelectricity_supplied_2 dropped due to collinearity  so we only tested regressors 3 and 4)
test(lelectricity_supplied_3=lelectricity_supplied_4)
*->conclude: we can pool the data across time

*Non-network models
quietly xtreg lindirect lcircuit_length_total_*, re i(year)
*lcircuit_length_total_1 and lcircuit_length_total_2 dropped due to collinearity, so we only tested regressors 3 and 4)
test (lcircuit_length_total_3= lcircuit_length_total_4)
*->conclude: we can pool the data across time

quietly xtreg lindirect lcircuit_length_total_* lelectricity_supplied_* icp_km_*, re i(year)
*regressors 1 and 2 dropped due to collinearity, so we only tested regressors 3 and 4, all icp_km drop due to collinearity
test (lcircuit_length_total_3= lcircuit_length_total_4)(lelectricity_supplied_3=lelectricity_supplied_4) 
*->conclude: we can pool the data across time

quietly xtreg lindirect lelectricity_supplied_*, re i(year)
*regressors 1 and 2 dropped due to collinearity, so we only tested regressors 3 and 4)
test(lelectricity_supplied_3=lelectricity_supplied_4)
*->conclude: we can pool the data across time
*/


